/*=============================================================================
Vitalnix/ACCDB - Unified Account Database
backends/slane.c - Server lane back-end
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
  -- License restrictions apply (Dual FAL/LGPL2)
  -- For details see doc/FAL.txt and doc/LGPL2.txt.
  $Id: slane.c,v 1.5 2004/06/07 09:29:07 hirogen2 Exp $
=============================================================================*/
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>

#include <libHX.h>
#include <accdb.h>
#include <accdb_int.h>

enum {
    CONF_READ = 0,
    CONF_FREE,
};

struct state {
    char *tcp_conn, *unix_conn;
};

static void read_config(struct state *, int);

MODULE_NAME("SLANE back-end");
MODULE_DESC("Server Lane support");
MODULE_INFO("Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004");

//-----------------------------------------------------------------------------
int q_open(struct accdb_module *mp) {
    struct state *sp;
    if((sp = mp->state = calloc(1, sizeof(struct state))) == NULL) {
        return -errno;
    }

    read_config(sp, CONF_READ);
    return 0;
}

//-----------------------------------------------------------------------------
int q_usertrav(struct accdb_module *mp, struct accdb_user *result) {
    return 0;
}

int q_userinfo(struct accdb_module *mp, struct accdb_user *rq,
 struct accdb_user *dest, size_t s) {
    return 0;
}

int q_useradd(struct accdb_module *mp, struct accdb_user *u) {
    return 0;
}

int q_usermod(struct accdb_module *mp, struct accdb_user *sm, struct accdb_user *mm) {
    return 0;
}

int q_userdel(struct accdb_module *mp, struct accdb_user *u) {
    return 0;
}

//-----------------------------------------------------------------------------
int q_grouptrav(struct accdb_module *mp, struct accdb_group *result) {
    return 0;
}

int q_groupinfo(struct accdb_module *mp, struct accdb_group *rq,
 struct accdb_group *dest, size_t s) {
    return 0;
}

int q_groupadd(struct accdb_module *mp, struct accdb_group *g) {
    return 0;
}

int q_groupmod(struct accdb_module *mp, struct accdb_group *sm,
 struct accdb_group *mm) {
    return 0;
}

int q_groupdel(struct accdb_module *mp, struct accdb_group *g) {
    return 0;
}

//-----------------------------------------------------------------------------
int q_close(struct accdb_module *mp) {
    struct state *sp = mp->state;
    read_config(sp, CONF_FREE);
    return 0;
}

long q_sysctl(unsigned int req, ...) {
    int rv = 1;
    switch(req) {
        case ACCDB_ADDFLAGS:
        case ACCDB_DELFLAGS:
            rv = 0;
            break;
        default:
            rv = -ENOSYS;
            break;
    }
    return rv;
}

//-----------------------------------------------------------------------------
static void read_config(struct state *sp, int f) {
    const char *paths[] = {"backends/../vetc", "/etc", NULL};
    struct rconfig_opt table[] = {
        {"TCP_CONN",  RCONF_STRING, &sp->tcp_conn, NULL, NULL},
        {"UNIX_CONN", RCONF_STRING, &sp->unix_conn, NULL, NULL},
        {NULL},
    };

    if(f == CONF_FREE) { HX_rconfig_free(table); }
    else { HX_rconfig_pv(paths, "libaccdb/slane", table, RCONFIG_ONE); }
    return;
}

//==[ End of file ]============================================================
