/*=============================================================================
Vitalnix/C-spark - User Management CLI/CUI
autorun.c
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
  -- License restrictions apply (Dual FAL/GPL2)
  -- For details see doc/FAL.txt and doc/GPL2.txt.
  $Id: autorun.c,v 1.11 2004/06/07 12:42:04 hirogen2 Exp $
=============================================================================*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <libHX.h>
#include <accdb.h>
#include "global.h"

//-----------------------------------------------------------------------------
// Password list printing (-P)

void autorun_pwl(struct pwl_param *i) {
    if(i->style == NULL || *i->style == '\0' || i->in == NULL ||
     *i->in == '\0' || i->out == NULL || *i->out == '\0') {
        fprintf(stderr, "--Pi, --Po and --Ps options are required for -P.\n"
         "(You will need to place them before -P itself.)\n");
        return;
    }

    pwl_proc(i);
    return;
}

//-----------------------------------------------------------------------------
// Synchronization (-S)

void autorun_sync(struct sync_param *i) {
    struct HXbtree *al = NULL, *lnlist = NULL;
    struct accdb_group dgroup;
    struct HXlld *dl = NULL;
    FILE *logp = NULL;
    char *outf;

    if(i->gname == NULL || *i->gname == '\0' || i->in == NULL ||
     *i->in == '\0') {
        fprintf(stderr, "--Sg and --Si options are required for -S.\n"
         "(You will need to place them before -S itself.)\n");
        return;
    }

    if((outf = i->out) == NULL) { outf = ""; }
    if(!Q_OPEN()) { exit(EXIT_FAILURE); }
    if(!sync_prep_dgrp(&dgroup, i->gname) || !sync_read_file(i->in, &al)) {
        goto out;
    }

    sync_compare(&dgroup, al, &dl, &lnlist);
    if(al->itemcount == 0 && dl->itemcount == 0) {
        printf("Already synchronized\n");
        goto out;
    }

    sync_fixup_addl(al, lnlist);
    sync_set_aflush();
    if(*outf != '\0' && (logp = sync_open_log(outf, 'w')) == NULL) {
        goto out;
    }

    if(al->itemcount > 0 && !sync_add(&dgroup, al, logp)) {
        printf("Error during operation. You might need to redo the"
         " Synchronization process\n" "to complete all jobs.\n");
        goto out2;
    }

    if(dl->itemcount > 0 && !sync_del(dl, logp)) {
        printf("Error during operation. You might need to redo the"
         " Synchronization process\n" "to complete all jobs.\n");
        //goto out2;
    }

out2:
    Q_SYSCTL(ACCDB_FLUSHDB);

out:
    if(logp != NULL) { fclose(logp); }
    sync_free(al, dl);
    Q_CLOSE();
    return;
}

//-----------------------------------------------------------------------------
// Adding a single user (-U)

void autorun_user(struct user_param *i) {
    struct HXbtree *al, *lnlist;
    struct accdb_group dgroup;
    struct ds_entry bucket;
    char buf[MAXSNLEN];

    if(i->gname == NULL || *i->gname == '\0' || i->vname == NULL ||
     *i->vname == '\0') {
        fprintf(stderr, "--Ug and --Uv options are required for -U.\n"
         "(You will need to place them before -U itself.)\n");
        return;
    }

    // i->nname can be empty

    if(!Q_OPEN()) { exit(EXIT_FAILURE); }
    if(!sync_prep_dgrp(&dgroup, i->gname)) { goto out; }

    bucket.vname = i->vname;
    bucket.nname = i->nname;
    bucket.sgroup = NULL;
    bucket.xuid = i->xuid;
    complete_pentry(&bucket, buf, MAXSNLEN);

    al = HXbtree_init(HXBT_ASSOC);
    HXbtree_add(al, buf, &bucket);

    sync_compare(&dgroup, al, NULL, &lnlist);
    sync_fixup_addl(al, lnlist);

    if(!sync_add(&dgroup, al, NULL)) {
        printf("Error during operation. You might need to redo the"
         " synchronization process\n" "to complete all jobs.\n");
    }

    Q_SYSCTL(ACCDB_FLUSHDB);
    /* We cannot call sync_free() as most of our data is present in the stack,
    which obviously cannot be freed. */
    free(bucket.lname);
    free(bucket.rname);
    HXbtree_free(al);

out:
    Q_CLOSE();
    return;
}

//==[ End of file ]============================================================
