/*=============================================================================
Vitalnix/C-spark - User Management CLI/CUI
global.h - Global header file
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2002 - 2004
  -- License restrictions apply (Dual FAL/GPL2)
  -- For details see doc/FAL.txt and doc/GPL2.txt.
  $Id: global.h,v 1.21 2004/09/10 06:19:56 hirogen2 Exp $
=============================================================================*/
#ifndef CSPARK_GLOBAL_H
#define CSPARK_GLOBAL_H 1

#ifdef __cplusplus
extern "C" {
#endif

#include <sys/types.h>
#include <stdio.h>
#include <libHX.h>
#include <accdb.h>
#include "cui/ds_entry.h"

#define LOGFMT_VERSION "0" // increment whenever ... the format changes
#define MAXFNLEN 512       // max length for filename buffer
#define MAXLNLEN 1024      // max length for line buffer
#define MAXSNLEN 128       // max length for a short line
#define P_MULTI(__var, __ext) __var, ((__var != 1) ? (__ext) : "")

#ifndef _WIN32 // Win32 specific hacks/defines
#    define stricmp(__a, __b) strcasecmp((__a), (__b))
#    define strnicmp(__a, __b, __s) strncasecmp((__a), (__b), (__s))
#endif

typedef unsigned char byte;

enum {
    AFLUSH_OFF = 0,
    AFLUSH_ON,
    AFLUSH_DEFAULT,
    AFLUSH_POSTADD,
};

// autorun.c
struct pwl_param {
    char *in, *out, *style, *tpl;
    // private section
    FILE *ifp, *ofp;
    void *styp;
    struct HXbtree *bt;
};

struct sync_param {
    char *gname, *in, *out;
};

struct user_param {
    char *vname, *nname, *xuid, *gname;
};

extern void autorun_pwl(struct pwl_param *);
extern void autorun_sync(struct sync_param *);
extern void autorun_user(struct user_param *);

// data.c
extern char *bday_to_xuid(const char *, char *, size_t);
extern int compare_wbc(const char *, const char *);
extern void complete_pentry(struct ds_entry *, char *, size_t);
extern int create_home(const char *, long, long);
extern int file_exists(const char *);
extern char *fixup_login_name(const char *, unsigned int, char *, size_t);
extern char *make_home(const char *, char *, size_t);
extern char *make_login_name(const char *, const char *);
extern long now_in_days(void);
extern char *now_in_ymdhms(char *, size_t);
extern int only_digits(const char *);
extern char *read_file(const char *);

// main.c
struct optmap_s {
    // general
    char *f_shell, // default shell for new users
         *f_skeld, // path to lockfile and skeleton dir (if any)
         *f_home;  // home base
    byte b_pwphon; // use phonetic passwords
    int  i_pswdlen;

    byte c_aflush, c_crymeth, c_split;

    // main.c
    char *progv, *progd, *f_lock, *module_path;
    byte nterm;

    // sync.c
    char *master_preadd, *master_postadd, *master_predel,
     *master_postdel, *user_preadd, *user_postadd, *user_predel,
     *user_postdel;
};

extern struct optmap_s Opt;
extern struct accdb_module *mm_output;

extern int Q_OPEN(void);
#define Q_USERTRAV(__res) (mm_output->usertrav(mm_output, (__res)))
#define Q_USERADD(__u) (mm_output->useradd(mm_output, (__u)))
#define Q_USERDEL(__rq) (mm_output->userdel(mm_output, (__rq)))
#define Q_USERINFO(__rq, __dest, __s) \
     (mm_output->userinfo(mm_output, (__rq), (__dest), (__s)))
#define Q_GROUPINFO(__rq, __dest, __s) \
     (mm_output->groupinfo(mm_output, (__rq), (__dest), (__s)))
#define Q_SYSCTL(__req, __args...) \
     (mm_output->sysctl((__req), mm_output, ## __args))
extern void Q_CLOSE(void);

// pwl.c
extern int pwl_proc(struct pwl_param *);
extern int pwl_needs_tpl(const char *);
extern void pwl_styles(void);

// sync.c
extern int sync_read_file(const char *, struct HXbtree **);
extern int sync_prep_dgrp(struct accdb_group *, const char *);
extern void sync_compare(struct accdb_group *, struct HXbtree *,
 struct HXlld **, struct HXbtree **);
extern void sync_fixup_addl(struct HXbtree *, struct HXbtree *);
extern void sync_set_aflush(void);
extern FILE *sync_open_log(const char *, char);
extern int sync_add(struct accdb_group *, struct HXbtree *, FILE *);
extern int sync_del(struct HXlld *, FILE *);
extern void sync_free(struct HXbtree *, struct HXlld *);

#ifdef __cplusplus
} // extern "C"
#endif

#endif // CSPARK_GLOBAL_H

//==[ End of file ]============================================================
