#!/bin/rpm
#==============================================================================
# Vitalnix - User Management Suite
# devutil/vitalnix.spec - RPM specfile
#   Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2003 - 2004
#   -- License restrictions apply (Dual FAL/LGPL2)
#   -- For details see doc/FAL.txt and doc/LGPL2.txt.
#   $Id: vitalnix.spec,v 1.15 2004/09/11 19:09:31 hirogen2 Exp $
#==============================================================================
Name: vitalnix
Version: 1.0.40.0
Release: 1
Group: System/Base
Packager: Jan Engelhardt <jengelh [at] linux01 gwdg de>
URL: http://%name.sf.net/
Summary: Vitalnix User Management Suite

Vendor: HX/Vitalnix
Source: http://prdownloads.sourceforge.net/%name/%name-%version.tbz2
%define source http://heanet.dl.sourceforge.net/sourceforge/%name/%name-%version.tbz2
License: FAL,GPL2,LGPL2

BuildRoot: %_tmppath/%name-%version-build
AutoReqProv: no
Provides: libaccdb.so.0.0
Requires: libHX.so.0.1 libc.so.6 libdl.so.2 libpopt.so.1 libpthread.so.0 libxml2.so.2

%description
Vitalnix is a User Management Suite, complete with a user database
framework and -capable tools, as well as CLIs (command line
interfaces) for administrating users.

ACCDB is the Unified Account Database, which provides a unified API
to all outside applications who wish to access the user database, be
it Shadow (/etc/passwd), LDAP, or anything else. The back-ends in
turn can do anything underneath it wishes or requires to, it is up to
the back-end. ACCDB can even use multiple user databases
simultaneously, if wanted.

It also comes with a tool, named C-Spark. It is a tool for the
automated mass (un) registration of users within the system user
database. It thus removes the need for adding each user manually.

(The goal of Vitalnix is to replace getpwent() with something new, and
especially, faster. Also, there is no getpwent() on Windows(R), so
this framework just comes at the right time.)

Author(s):
----------
  Jan Engelhardt <jengelh [at] linux01 gwdg de>
  (Contributors see doc/index.html)

#------------------------------------------------------------------------------
%prep
cd "$RPM_SOURCE_DIR"/;
copy_from_local=0;
if [ ! -e %name-%version.tbz2 ]; then
    if [ -d /home/hirogen2/f/%name ]; then
        copy_from_local=1;
    else
        wget -c %source;
    fi;
fi;

cd "$RPM_BUILD_DIR"/;
rm -Rf %name %name-%version;
if [ $copy_from_local -eq 1 ]; then
    cp -Rav /home/hirogen2/f/%name ./;
    mv %name %name-%version;
    make -C %name-%version cleanx;
else
    tar -jvxf %name-%version.tbz2;
fi;

find %name-%version -type d -name CVS -print0 | xargs -0 rm -Rfv;

#------------------------------------------------------------------------------
%build
cd "$RPM_BUILD_DIR"/%name-%version/;
numcpu=$[`grep ^processor /proc/cpuinfo | wc -l`+1];

%ifarch i686
./Makefile.RUN -j$numcpu DEBUG=0 VERBOSE=1 MARCH=i686 MCPU=i686;
%else
%ifarch i586
./Makefile.RUN -j$numcpu DEBUG=0 VERBOSE=1 MARCH=i586 MCPU=i586;
%else
./Makefile.RUN -j$numcpu DEBUG=0 VERBOSE=1;
%endif
%endif

#------------------------------------------------------------------------------
%install
prefix="$RPM_BUILD_ROOT";
[ "$prefix" != / -a -d "$prefix" ] && rm -Rfv "$prefix";
cd "$RPM_BUILD_DIR"/%name-%version/;

bindir="$prefix/bin";
etcdir="$prefix/etc";
usrbin="$prefix/usr/bin";
usrinc="$prefix/usr/include";
usrlib="$prefix/usr/lib";
usrsbin="$prefix/usr/sbin";
varlib="$prefix/var/lib";
usrdoc="$prefix""%_defaultdocdir";

# [accdb] libaccdb
install -dp "$etcdir"/libaccdb;
install -dp "$usrinc";
install -dp "$usrlib";
install -pm0644 vetc/autouid "$etcdir"/;
install -pm0644 vetc/libaccdb/accdb "$etcdir"/libaccdb/;
install -pm0644 include/accdb.h include/accdb_int.h "$usrinc"/;
install -pm0755 libaccdb.so.0.0 "$usrlib"/;
ln -fs libaccdb.so.0.0 "$usrlib"/libaccdb.so;

# [backends] ACCDB backend modules
install -dp "$etcdir"/libaccdb;
install -dp "$usrlib";
install -pm0644 vetc/libaccdb/{mig,shadow,slane} "$etcdir"/libaccdb/;
install -pm0755 accdb_{dummy,mig,shadow,slane}.so "$usrlib"/;

# [cui/cspark] SparkUI
install -dp "$usrlib"/%name;
install -pm0755 cspark "$usrlib"/%name;
install -pm0644 vetc/spark.cfg "$usrlib"/%name;

# [sysprog] Vitalnix System Programs
install -dp "$etcdir";
install -dp "$usrsbin";
install -pm0644 vetc/{user,group}{add,mod,del}.conf "$etcdir"/;
install -pm0644 vetc/slaned.cfg "$etcdir"/;
install -pm0755 v{user,group}{add,mod,del} "$usrsbin"/;
install -pm0755 slaned "$usrsbin"/;

# [supply] Vitalnix Supply Programs
install -dp "$etcdir"/init.d;
install -dp "$usrlib"/%name;
install -pm0755 accdbinfo "$usrlib"/vitalnix;
install -pm0755 supply/{mkgroupdir,sb_DE.tex,sdf2xml,sg.rtf,sg_DE.rtf,sort_pwf} "$usrlib"/vitalnix;
install -pm0755 supply/slaned "$etcdir"/init.d/slaned;

# [doc] Vitalnix Documentation
install -d "$usrdoc";
cp -av doc "$usrdoc"/%name;

#------------------------------------------------------------------------------
# "win32$" tags for "makezip" program
%files
%defattr(-,root,root)

# [accdb] libaccdb
%config /etc/autouid
%config /etc/libaccdb/accdb
/usr/include/accdb.h
/usr/include/accdb_int.h
/usr/lib/libaccdb.so
/usr/lib/libaccdb.so.0.0
#win32$ vetc/autouid
#win32$ vetc/libaccdb/accdb
#win32$ include/accdb.h
#win32$ include/accdb_int.h
#win32$ libaccdb.0.0.dll

# [backends] ACCDB backend modules
#%config /etc/libaccdb/mig
%config /etc/libaccdb/shadow
#%config /etc/libaccdb/slane
/usr/lib/accdb_dummy.so
#/usr/lib/accdb_mig.so
/usr/lib/accdb_shadow.so
#/usr/lib/accdb_slane.so
##win32$ vetc/libaccdb/mig
#win32$ vetc/libaccdb/shadow
##win32$ vetc/libaccdb/slane
#win32$ accdb_dummy.dll
##win32$ accdb_mig.dll
#win32$ accdb_shadow.dll
##win32$ accdb_slane.dll

# [cui/cspark] SparkUI
%config /usr/lib/vitalnix/spark.cfg
/usr/lib/vitalnix/cspark
#/var/lib/vitalnix
#win32$ vetc/spark.cfg
#win32$ cspark.exe

# [sysprog] Vitalnix System Programs
%config /etc/useradd.conf
%config /etc/usermod.conf
%config /etc/userdel.conf
%config /etc/groupadd.conf
%config /etc/groupmod.conf
%config /etc/groupdel.conf
#%config /etc/slaned.cfg
/usr/sbin/vuseradd
/usr/sbin/vusermod
/usr/sbin/vuserdel
/usr/sbin/vgroupadd
/usr/sbin/vgroupmod
/usr/sbin/vgroupdel
#/usr/sbin/slaned
#win32$ vetc/useradd.conf
#win32$ vetc/usermod.conf
#win32$ vetc/userdel.conf
#win32$ vetc/groupadd.conf
#win32$ vetc/groupmod.conf
#win32$ vetc/groupdel.conf
#win32$ vuseradd.exe
#win32$ vusermod.exe
#win32$ vuserdel.exe
#win32$ vgroupadd.exe
#win32$ vgroupmod.exe
#win32$ vgroupdel.exe

# [supply] Vitalnix Supply Programs
#/etc/init.d/slaned
%dir /usr/lib/%name
/usr/lib/%name/accdbinfo
# Flagged as config since you might have changed these
%config /usr/lib/%name/mkgroupdir
%config /usr/lib/%name/sb_DE.tex
%config /usr/lib/%name/sdf2xml
%config /usr/lib/%name/sg.rtf
%config /usr/lib/%name/sg_DE.rtf
%config /usr/lib/%name/sort_pwf
#win32$ accdbinfo.exe
#win32$ supply/mkgroupdir
#win32$ supply/sb_DE.tex
#win32$ supply/sdf2xml
#win32$ supply/sg.rtf
#win32$ supply/sg_DE.rtf
#win32$ supply/sort_pwf

# [doc] Vitalnix Documentation
%docdir %_defaultdocdir/%name
%_defaultdocdir/%name
#win32$ doc

# [win32] Additional libraries needed
#win32$ libHX.0.0.dll
#win32$ libiconv-2.dll
#win32$ libintl-2.dll
#win32$ libtrio.dll
#win32$ libxml2.dll
#win32$ popt1.dll

#==[ End of file ]=============================================================
