/*=============================================================================
Vitalnix/ACCDB - Unified Account Database
include/accdb.h - Include file for ACCDB back-end mod.s or apps utilizing them
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2003 - 2004
  -- License restrictions apply (Dual FAL/LGPL2)
  -- For details see doc/FAL.txt and doc/LGPL2.txt.
  $Id: accdb.h,v 1.13 2004/06/10 07:34:02 hirogen2 Exp $
=============================================================================*/
#ifndef _ACCDB_H
#define _ACCDB_H 1

#include <sys/types.h>

#ifdef __cplusplus
extern "C" {
#endif

struct accdb_user {
    // passwd part
    char *lname;
    long uid, gid;
    char *gecos, *home, *shell, *igrp, *sgrp;

    // shadow part
    char *passwd;
    long last_change, keep_min, keep_max, warn_age, expire, inactive;
    void *_private;
};

struct accdb_group {
    char *gname;
    long gid;
    void *_private;
};

struct accdb_module {
    const char *name, *desc, *info;
    void *handle, *state;
    int (*init)(struct accdb_module *, const char *);
    int (*open)(struct accdb_module *);
    int (*usertrav)(struct accdb_module *, struct accdb_user *);
    int (*userinfo)(struct accdb_module *, struct accdb_user *,
     struct accdb_user *, size_t);
    int (*useradd)(struct accdb_module *, struct accdb_user *);
    int (*usermod)(struct accdb_module *, struct accdb_user *,
     struct accdb_user *);
    int (*userdel)(struct accdb_module *, struct accdb_user *);
    int (*grouptrav)(struct accdb_module *, struct accdb_group *);
    int (*groupinfo)(struct accdb_module *, struct accdb_group *,
     struct accdb_group *, size_t);
    int (*groupadd)(struct accdb_module *, struct accdb_group *);
    int (*groupmod)(struct accdb_module *, struct accdb_group *,
     struct accdb_group *);
    int (*groupdel)(struct accdb_module *, struct accdb_group *);
    int (*close)(struct accdb_module *);
    long (*sysctl)(unsigned int, ...);
    void (*deinit)(struct accdb_module *);
};

enum accdb_crypt_meth {
    CRYPW_DES = 1,
    CRYPW_MD5,
    CRYPW_BLOWFISH,
};

struct accdb_cryptinfo {
    // Input fields
    unsigned char *key;
    int method;

    // Output fields
    unsigned char *crypted;
};

enum {
    GENPW_PHONEMIC  = 1 << 0,
    GENPW_ONE_DIGIT = 1 << 1,
    GENPW_ONE_CASE  = 1 << 2,
};

enum {
    ACCDB_AFLUSH = 1 << 0,
};

enum accdb_sysctl_req {
    ACCDB_ADDFLAGS = 0x1,
    ACCDB_DELFLAGS,
    ACCDB_FLUSHDB,
    ACCDB_COUNT_USERS,
    ACCDB_COUNT_GROUPS,

    ACCDB_NEXTUID_SYS = 0x100,
    ACCDB_NEXTUID,
    ACCDB_NEXTGID_SYS,
    ACCDB_NEXTGID,

    ACCDB_LOCK_EXCL = 0xA000,
    ACCDB_UNLOCK_EXCL,

    ACCDB_MODSPEC = 0xC000,
    /* Module specific sysctl requests shall start at 0xC000, thus use
    something like "case ACCDB_MODSPEC + 1:" */
};

extern struct accdb_module *accdb_load(const char *);
extern void accdb_unload(struct accdb_module *);
extern int accdb_genpw(char *, size_t, unsigned long);
extern int accdb_cryptpw(const char *, const char *, int, char **);

#ifdef __cplusplus
} // extern "C"
#endif

#endif // _ACCDB_H

//==[ End of file ]============================================================
